pub struct UpdatesStateSnap {
pub pts: i32,
pub qts: i32,
pub date: i32,
pub seq: i32,
pub channels: Vec<(i64, i32)>,
}Expand description
Snapshot of the MTProto update-sequence state that we persist so that
catch_up: true can call updates.getDifference with the pre-shutdown pts.
Fields
pts: i32Main persistence counter (messages, non-channel updates).
qts: i32Secondary counter for secret chats.
date: i32Date of the last received update (Unix timestamp).
seq: i32Combined-container sequence number.
channels: Vec<(i64, i32)>Per-channel persistence counters. (channel_id, pts).
Implementations
Sourceimpl UpdatesStateSnap
impl UpdatesStateSnap
Sourcepub fn is_initialised(&self) -> bool
pub fn is_initialised(&self) -> bool
Returns true when we have a real state from the server (pts > 0).
Sourcepub fn set_channel_pts(&mut self, channel_id: i64, pts: i32)
pub fn set_channel_pts(&mut self, channel_id: i64, pts: i32)
Advance (or insert) a per-channel pts value.
Sourcepub fn channel_pts(&self, channel_id: i64) -> i32
pub fn channel_pts(&self, channel_id: i64) -> i32
Look up the stored pts for a channel, returns 0 if unknown.